@@ -4,6 +4,7 @@ from typing import Sequence
 from typing import Union as U
 
 from h5py import File
+import torch
 from torch.utils.data import Dataset
 from torchvision.transforms import Compose
 
@@ -128,4 +129,4 @@ class PCAM(Dataset):
         if self.transform:
             image = self.transform(image)
 
-        return {"data": image, "feature": label}
+        return {"data": image, "feature": torch.as_tensor(label).type(torch.LongTensor)}
